@@ -1,4 +1,4 @@
-/* Out-of-memory and NULL pointer error exit calls
+/* libjodycoe: out-of-memory and NULL pointer error exits
  *
  * Copyright (C) 2021-2025 by Jody Bruchon <jody@jodybruchon.com>
  * Released under The MIT License
@@ -11,7 +11,7 @@
 static const char msg_unknown[] = "(unknown)";
 
 /* Out of memory failure */
-extern void jc_oom(const char * restrict msg)
+void jc_oom(const char * restrict msg)
 {
 	if (msg == NULL) msg = msg_unknown;
 	fprintf(stderr, "\nout of memory: %s\n", msg);
@@ -19,7 +19,7 @@ extern void jc_oom(const char * restrict msg)
 }
 
 /* Null pointer failure */
-extern void jc_nullptr(const char * restrict func)
+void jc_nullptr(const char * restrict func)
 {
 	if (func == NULL) func = msg_unknown;
 	fprintf(stderr, "\ninternal error: NULL pointer caught at %s\n", func);
